# PoreAna: An Analysis Tool for Pore Simulations

[![PyPI Version](https://img.shields.io/badge/PyPI-0.2.0-orange)](https://pypi.org/project/PoreAna/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://github.com/Ajax23/PoreAna/blob/master/LICENSE)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4738182.svg)](https://doi.org/10.5281/zenodo.4738182)
[![Build Status](https://travis-ci.com/Ajax23/PoreAna.svg?branch=master)](https://travis-ci.com/Ajax23/PoreAna)
[![codecov](https://codecov.io/gh/Ajax23/PoreAna/branch/master/graph/badge.svg)](https://codecov.io/gh/Ajax23/PoreAna)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/Ajax23/PoreAna.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/Ajax23/PoreAna/context:python)

## Documentation

Online documentation is available at [ajax23.github.io/PoreAna](http://ajax23.github.io/PoreAna).

The docs include an example for analyzing [density](http://ajax23.github.io/PoreAna/density.html) and [diffusion](http://ajax23.github.io/PoreAna/diffusion.html), and an [API reference](http://ajax23.github.io/PoreAna/api.html).


## Dependencies

PoreAna supports Python 3.5+.

Installation requires [numpy](https://pypi.org/project/numpy/), [pandas](https://pypi.org/project/pandas/), [chemfiles 0.10.0](https://pypi.org/project/chemfiles/0.8.0/), [seaborn](https://pypi.org/project/seaborn/) and [porems](https://pypi.org/project/porems/).


## Installation

You may instead want to use the development version from GitHub:

    pip install git+https://github.com/ajax23/PoreAna.git#egg=poreana

    pip install git+https://github.com/ajax23/PoreAna.git@develop#egg=poreana

Or download the repository and install in the top directory via:

    pip install .


## Testing

To test PoreAna, run the test in the test directory.


## Development

PoreAna development takes place on Github: [www.github.com/Ajax23/PoreAna](https://github.com/Ajax23/PoreAna)

Please submit any reproducible bugs you encounter to the [issue tracker](https://github.com/Ajax23/PoreAna/issues).


## How to Cite PoreAna

When citing PoreAna please use the current **Zenodo DOI** corresponding to the used PoreAna version. (Current DOI is listed in the badges.)
